@@ -33,6 +33,8 @@ import urllib3
 
 from urllib3.exceptions import InsecureRequestWarning
 from .scanossbase import ScanossBase
+from . import __version__
+
 
 DEFAULT_URL = "https://osskb.org/api/scan/direct"  # default free service URL
 DEFAULT_URL2 = "https://scanoss.com/api/scan/direct"  # default premium service URL
@@ -85,6 +87,8 @@ class ScanossApi(ScanossBase):
         if self.api_key:
             self.headers['X-Session'] = self.api_key
             self.headers['x-api-key'] = self.api_key
+        self.headers['User-Agent'] = f'scanoss-py/{__version__}'
+        self.headers['user-agent'] = f'scanoss-py/{__version__}'
         self.sbom = None
         self.load_sbom()  # Load an input SBOM if one is specified
         if self.trace:
@@ -165,6 +169,12 @@ class ScanossApi(ScanossBase):
                     else:
                         self.print_stderr(f'Warning: No response received from {self.url}. Retrying...')
                         time.sleep(5)
+                elif r.status_code == 503:  # Service limits have most likely been reached
+                    self.print_stderr(f'ERROR: SCANOSS API rejected the scan request ({request_id}) due to '
+                                      f'service limits being exceeded')
+                    self.print_stderr(f'ERROR: Details: {r.text.strip()}')
+                    raise Exception(f"ERROR: {r.status_code} - The SCANOSS API request ({request_id}) rejected "
+                                    f"for {self.url} due to service limits being exceeded.")
                 elif r.status_code >= 400:
                     if retry > 5:  # No response 5 or more times, fail
                         self.save_bad_req_wfp(scan_files, request_id, scan_id)
